@@ -12,7 +12,7 @@
 /* map_list
  *
  */
-SEXP map_list(SEXP (*const f)(SEXP), const SEXP list);
+SEXP map_list(SEXP (*const f)(SEXP), SEXP list);
 
 /* make_alist
  *
@@ -22,17 +22,17 @@ SEXP make_alist();
 /* add_alist
  *
  */
-SEXP add_alist(const SEXP key, const SEXP value, const SEXP alist);
+SEXP add_alist(SEXP key, SEXP value, SEXP alist);
 
 /* get_alist
  *
  */
-SEXP get_alist(const SEXP key, const SEXP alist);
+SEXP get_alist(SEXP key, SEXP alist);
 
 /* contains_alist
  *
  */
-Rboolean contains_alist(const SEXP key, const SEXP alist);
+Rboolean contains_alist(SEXP key, SEXP alist);
 
 // TODO
 
